@@ -6,13 +6,22 @@
 class YDialog: public YFrameClient {
 public:
     YDialog(YWindow *owner = 0);
+    virtual ~YDialog();
 
-    void paint(Graphics &g, int x, int y, unsigned int width, unsigned int height);
+    void paint(Graphics &g, const YRect &r);
     virtual bool handleKey(const XKeyEvent &key);
 
+#ifdef CONFIG_GRADIENTS
+    virtual ref<YImage> getGradient() const { return fGradient; }
+#endif
     YWindow *getOwner() const { return fOwner; }
+
 private:
     YWindow *fOwner;
+
+#ifdef CONFIG_GRADIENTS
+    ref<YImage> fGradient;
+#endif
 };
 
 #endif
